<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>AddExistingDocumentDialog</name>
    <message>
        <source>add_existing_document_caption</source>
        <translation type="obsolete">Add existing document</translation>
    </message>
    <message>
        <source>document_url_label</source>
        <translation type="obsolete">Document location:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="14"/>
        <source>Add existing document</source>
        <translation>Přidat stávající dokument</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="51"/>
        <source>Document location:</source>
        <translation>Umístění dokumentu:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="61"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="68"/>
        <source>Document format:</source>
        <translation>Formát dokumentu:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="78"/>
        <source>Force read-only mode</source>
        <translation>Vynutit režim pouze pro čtení</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="98"/>
        <source>Custom settings</source>
        <translation>Vlastní nastavení</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="105"/>
        <source>Save file to disk before opening</source>
        <translation>Uložit soubor na disk před otevřením</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="143"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddExistingDocumentDialog.ui" line="153"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>force_format_label</source>
        <translation type="obsolete">Document format:</translation>
    </message>
    <message>
        <source>force_read_only_label</source>
        <translation type="obsolete">Force read-only mode</translation>
    </message>
    <message>
        <source>add_button</source>
        <translation type="obsolete">Add</translation>
    </message>
    <message>
        <source>cancel_button</source>
        <translation type="obsolete">Cancel</translation>
    </message>
    <message>
        <source>custom_format_settings</source>
        <translation type="obsolete">Custom settings</translation>
    </message>
    <message>
        <source>save2disk_label</source>
        <translation type="obsolete">Save file to disk before opening</translation>
    </message>
</context>
<context>
    <name>AddNewDocumentDialog</name>
    <message>
        <source>add_new_document_caption</source>
        <translation type="obsolete">Add new document</translation>
    </message>
    <message>
        <source>document_type_label</source>
        <translation type="obsolete">Document format</translation>
    </message>
    <message>
        <source>document_url_label</source>
        <translation type="obsolete">Document location</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="14"/>
        <source>Add new document</source>
        <translation>Přidat nový dokument</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="50"/>
        <source>Document format</source>
        <translation>Formát dokumentu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="60"/>
        <source>Document location</source>
        <translation>Umístění dokumentu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="70"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="97"/>
        <source>Compress file</source>
        <translation>Zhustit soubor</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="137"/>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AddNewDocumentDialog.ui" line="144"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>create_button</source>
        <translation type="obsolete">Create</translation>
    </message>
    <message>
        <source>cancel_button</source>
        <translation type="obsolete">Cancel</translation>
    </message>
    <message>
        <source>compress_check</source>
        <translation type="obsolete">Compress file</translation>
    </message>
</context>
<context>
    <name>AnnotationSettingsDialog</name>
    <message>
        <source>annotation_settings_dialog_title</source>
        <translation type="obsolete">Visualization settings for annotations</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="13"/>
        <source>Visualization settings for annotations</source>
        <translation>Nastavení znázornění pro poznámky</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="26"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="31"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="36"/>
        <source>Amino</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="41"/>
        <source>Highlight</source>
        <translation>Zvýraznit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="69"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="82"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="46"/>
        <source>Visual Qualifier</source>
        <translation>Viditelný modifikátor</translation>
    </message>
</context>
<context>
    <name>CopyDocumentDialog</name>
    <message>
        <source>Copy Document</source>
        <translation type="obsolete">Copy document</translation>
    </message>
    <message>
        <source>File name:</source>
        <translation type="obsolete">Document location</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation type="obsolete">Document format</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="14"/>
        <source>Save a copy</source>
        <translation>Uložit kopii</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="25"/>
        <source>Save to file</source>
        <translation>Uložit do souboru</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="32"/>
        <source>File format</source>
        <translation>Souborový formát</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="52"/>
        <source>Add to project</source>
        <translation>Přidat do projektu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="45"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="62"/>
        <source>Compress file</source>
        <translation>Zhustit soubor</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="89"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CopyDocumentDialog.ui" line="96"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>CreateAnnotationWidget</name>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="54"/>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="82"/>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="117"/>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <source>create_annotation_widget</source>
        <translation type="obsolete">Create annotations</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="35"/>
        <source>Save annotation(s) to</source>
        <translation>Uložit poznámku(y) do</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="41"/>
        <source>Existing annotation table</source>
        <translation>Tabulka stávajících poznámek</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="65"/>
        <source>Create new table</source>
        <translation>Vytvořit novou tabulku</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="92"/>
        <source>Annotation parameters</source>
        <translation>Parametry poznámek</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="104"/>
        <source>Group name</source>
        <translation>Název skupiny</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="114"/>
        <source>Predefined group names</source>
        <translation>Předem určené názvy skupin</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="134"/>
        <source>Annotation name</source>
        <translation>Název poznámky</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="168"/>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="148"/>
        <source>Predefined annotation names</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="26"/>
        <source>Create annotations</source>
        <translation>Vytvořit poznámky</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="175"/>
        <source>Annotation location in GenBank format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateAnnotationWidget.ui" line="182"/>
        <source>Add/remove complement flag</source>
        <translation>Přidat/Odstranit příznak doplňku</translation>
    </message>
</context>
<context>
    <name>CreateDocumentFromTextDialog</name>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="14"/>
        <source>Create document</source>
        <translation>Vytvořit dokument</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="22"/>
        <source>Document location:</source>
        <translation>Umístění dokumentu:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="32"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="39"/>
        <source>Document format:</source>
        <translation>Formát dokumentu:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="49"/>
        <source>Sequence name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="56"/>
        <source>Sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="87"/>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">Create</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="94"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateDocumentFromTextDialog.ui" line="65"/>
        <source>Save file immediately</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CreateNewObjectDialog</name>
    <message>
        <source>object_name_label</source>
        <translation type="obsolete">Object name</translation>
    </message>
    <message>
        <source>object_type_label</source>
        <translation type="obsolete">Object type</translation>
    </message>
    <message>
        <source>object_document_label</source>
        <translation type="obsolete">Document</translation>
    </message>
    <message>
        <source>create_new_document_buton</source>
        <translation type="obsolete">...</translation>
    </message>
    <message>
        <source>create_button</source>
        <translation type="obsolete">Create</translation>
    </message>
    <message>
        <source>cancel_button</source>
        <translation type="obsolete">Cancel</translation>
    </message>
    <message>
        <source>create_new_object_dialog_caption</source>
        <translation type="obsolete">Create new object</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="14"/>
        <source>Create new object</source>
        <translation>Vytvořit nový předmět</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="39"/>
        <source>Object name</source>
        <translation>Název předmětu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="49"/>
        <source>Object type</source>
        <translation>Typ předmětu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="59"/>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="69"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="113"/>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateNewObjectDialog.ui" line="120"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>CreateObjectRelationDialog</name>
    <message>
        <source>create_object_relation_title</source>
        <translation type="obsolete">Edit object relations</translation>
    </message>
    <message>
        <source>relation_hint</source>
        <translation type="obsolete">Associate object with:</translation>
    </message>
    <message>
        <source>ok_button</source>
        <translation type="obsolete">Ok</translation>
    </message>
    <message>
        <source>cancel_button</source>
        <translation type="obsolete">Cancel</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateObjectRelationDialog.ui" line="13"/>
        <source>Edit object relations</source>
        <translation>Upravit vztahy mezi předměty</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateObjectRelationDialog.ui" line="19"/>
        <source>Associate object with:</source>
        <translation>Spojit předmět s:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateObjectRelationDialog.ui" line="44"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/CreateObjectRelationDialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>DownloadRemoteFileDialog</name>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="14"/>
        <source>Fetch data from remote database</source>
        <translation>Natáhnout data ze vzdálené databáze</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="22"/>
        <source>Resource ID:</source>
        <translation>ID zdroje:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="32"/>
        <source>Database:</source>
        <translation>Databáze:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="49"/>
        <source>Save to directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="61"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="90"/>
        <source>Hint</source>
        <translation>Rada</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="97"/>
        <source>Use database unique identifier.</source>
        <translation>Použít jedinečný databázový identifikátor.</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="135"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/DownloadRemoteFileDialog.ui" line="142"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>EditQualifierDialog</name>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="14"/>
        <source>Edit qualifier</source>
        <translation>Upravit modifikátor</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="22"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="38"/>
        <source>Value</source>
        <translation>Hodnota</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="77"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditQualifierDialog.ui" line="67"/>
        <source>OK</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>EditSequenceDialog</name>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="20"/>
        <source>Annotations region resolving mode</source>
        <translation type="unfinished">Annotated regions resolving</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="28"/>
        <source>Resize</source>
        <translation type="unfinished">Resize</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="38"/>
        <source>Remove</source>
        <translation type="unfinished">Remove</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="45"/>
        <source>Split</source>
        <translation type="unfinished">Split</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="59"/>
        <source>Position to insert</source>
        <translation type="unfinished">Start position</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="91"/>
        <source>Save to new file</source>
        <translation type="unfinished">Save resulted document to a new file</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="105"/>
        <source>Document location:</source>
        <translation type="unfinished">Document location:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="115"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="122"/>
        <source>Document format:</source>
        <translation type="unfinished">Document format:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="134"/>
        <source>Merge annotations to this file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="159"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/EditSequenceDialog.ui" line="166"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>FormatSettingsDialog</name>
    <message>
        <location filename="../src/util_gui/ui/FormatSettingsDialog.ui" line="13"/>
        <source>Custom settings</source>
        <translation>Nastavení vlastního formátu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/FormatSettingsDialog.ui" line="34"/>
        <source>Save as default settings</source>
        <translation>Uložit jako výchozí nastavení</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/FormatSettingsDialog.ui" line="54"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/FormatSettingsDialog.ui" line="61"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>MultipartDocFormatConfiguratorWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Create annotation</translation>
    </message>
    <message>
        <source>separate_label</source>
        <translation type="obsolete">Separate sequences</translation>
    </message>
    <message>
        <source>merge_label</source>
        <translation type="obsolete">Merge sequences</translation>
    </message>
    <message>
        <source>gap_label</source>
        <translation type="obsolete">Gap length:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/MultipartDocFormatConfiguratorWidget.ui" line="19"/>
        <source>Create annotation</source>
        <translation type="unfinished">Create annotation</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/MultipartDocFormatConfiguratorWidget.ui" line="25"/>
        <source>Separate sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/MultipartDocFormatConfiguratorWidget.ui" line="32"/>
        <source>Merge sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/MultipartDocFormatConfiguratorWidget.ui" line="41"/>
        <source>Gap length:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProjectTreeItemSelectorDialogBase</name>
    <message>
        <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="13"/>
        <source>Select Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="20"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="43"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="53"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>RemovePartFromSequenceDialog</name>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="14"/>
        <source>Remove subsequence</source>
        <translation>Odstranit podsekvenci</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="22"/>
        <source>Region to remove</source>
        <translation>Oblast k odstranění</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">Remove</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="69"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="78"/>
        <source>Annotations region resolving mode</source>
        <translation>Režim vyřešení oblasti opatřené poznámkami</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="86"/>
        <source>Resize</source>
        <translation>Změnit velikost</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="62"/>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="96"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="111"/>
        <source>Save to new file</source>
        <translation>Uložit výsledný dokument do nového souboru</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="123"/>
        <source>Merge annotations to this file</source>
        <translation>Sloučit poznámky do tohoto souboru</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="132"/>
        <source>Document location:</source>
        <translation>Vyberte umístění dokumentu:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="142"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/RemovePartFromSequenceDialog.ui" line="149"/>
        <source>Document format:</source>
        <translation>Formát dokumentu:</translation>
    </message>
</context>
<context>
    <name>SelectFormatToSaveDialog</name>
    <message>
        <location filename="../src/util_gui/ui/SelectFormatToSaveDialog.ui" line="13"/>
        <source>Select format to save sequence</source>
        <translation>Vyberte formát pro uložení sekvence</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SelectFormatToSaveDialog.ui" line="37"/>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">Create</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SelectFormatToSaveDialog.ui" line="44"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>SeqPasterWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Create annotation</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="26"/>
        <source>Paste data here</source>
        <translation>Zde vložit data:</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation type="obsolete">Custom settings</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="14"/>
        <source>Create annotation</source>
        <translation>Vytvořit poznámku</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="43"/>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="53"/>
        <source>Custom settings</source>
        <translation>Vlastní nastavení</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="59"/>
        <source>Alphabet:</source>
        <translation>Abeceda:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="69"/>
        <source>Skip unknown symbols</source>
        <translation>Přeskočit neznámé symboly</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ui/SeqPasterWidget.ui" line="79"/>
        <source>Replace unknown symbols with</source>
        <translation>Neznámé symboly nahradit</translation>
    </message>
</context>
<context>
    <name>SeqPasterWidgetController</name>
    <message>
        <location filename="../src/util_gui/SeqPasterWidgetController.cpp" line="55"/>
        <source>Input sequence is empty</source>
        <translation>Vstupní sekvence je prázdná</translation>
    </message>
    <message>
        <location filename="../src/util_gui/SeqPasterWidgetController.cpp" line="59"/>
        <source>Replace symbol is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/SeqPasterWidgetController.cpp" line="75"/>
        <source>Alphabet not detected</source>
        <translation>Nelze určit abecedu</translation>
    </message>
</context>
<context>
    <name>U2::AddExistingDocumentDialogImpl</name>
    <message>
        <source>open_file_dialog_caption</source>
        <translation type="obsolete">Select document to add</translation>
    </message>
    <message>
        <source>dwnld_file_dialog_caption</source>
        <translation type="obsolete">Save as</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">Error!</translation>
    </message>
    <message>
        <source>url_is_empty</source>
        <translation type="obsolete">Document URL is empty!</translation>
    </message>
    <message>
        <source>document_is_already_added</source>
        <translation type="obsolete">Document is already added!</translation>
    </message>
    <message>
        <source>no_format_selected</source>
        <translation type="obsolete">Document format is not selected!</translation>
    </message>
    <message>
        <source>no_io_adapter_found</source>
        <translation type="obsolete">IO adapter not found!</translation>
    </message>
    <message>
        <source>project_is_locked</source>
        <translation type="obsolete">Project is locked</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="149"/>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="155"/>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="161"/>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="167"/>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="173"/>
        <source>Error!</source>
        <translation>Chyba!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="65"/>
        <source>Project is locked</source>
        <translation>Projekt je uzamknut</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="86"/>
        <source>Open file</source>
        <translation>Vyberte dokument, který se má přidat</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="149"/>
        <source>File %1 does not exist!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="155"/>
        <source>Document URL is empty!</source>
        <translation>Adresa dokumentu (URL) je prázdná!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="161"/>
        <source>Document is already added!</source>
        <translation>Dokument je již přidán!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="167"/>
        <source>Document format is not selected!</source>
        <translation>Formát dokumentu není vybrán!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="173"/>
        <source>IO adapter not found!</source>
        <translation>IO adaptér nenalezen!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddExistingDocumentDialogImpl.cpp" line="184"/>
        <source>Save as</source>
        <translation>Uložit jako</translation>
    </message>
</context>
<context>
    <name>U2::AddNewDocumentDialogImpl</name>
    <message>
        <source>save_file_dialog_caption</source>
        <translation type="obsolete">Save file</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">Error!</translation>
    </message>
    <message>
        <source>project_is_locked</source>
        <translation type="obsolete">Project is locked</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="obsolete">Error!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddNewDocumentDialogImpl.cpp" line="48"/>
        <source>Project is locked</source>
        <translation>Projekt je uzamknut</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AddNewDocumentDialogImpl.cpp" line="114"/>
        <source>Save file</source>
        <translation>Uložit soubor</translation>
    </message>
</context>
<context>
    <name>U2::AddToViewTask</name>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="76"/>
        <source>Add object to view %1</source>
        <translation>Přidat předmět do pohledu %1</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="91"/>
        <source>Document was removed %1</source>
        <translation>Dokument byl odstraněn %1</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="96"/>
        <source>Object not found %1</source>
        <translation>Předmět nebyl nalezen %1</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="100"/>
        <source>View was closed %1</source>
        <translation>Pohled byl zavřen %1</translation>
    </message>
</context>
<context>
    <name>U2::AnnotationSettingsDialogImpl</name>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="38"/>
        <source>Annotation name</source>
        <translation>Název poznámky</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="39"/>
        <source>A color used to highlight annotation</source>
        <translation>Barva použitá ke zvýraznění poznámky</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="40"/>
        <source>If checked the annotation will be shown on amino strand</source>
        <translation>Je-li zaškrtnuto, poznámka bude ukazována při amino řetězci</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="41"/>
        <source>If unchecked the annotation will not be highlighted with color</source>
        <translation>Není-li zaškrtnuto, poznámka nebude zvýrazňována barvou</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="42"/>
        <source>A comma-separated list of qualifier names.&lt;br&gt; The value of qualifiers will be shown instead of the annotation names in PanView</source>
        <translation>Čárkou oddělený seznam názvů modifikátorů&lt;br&gt; Hodnota modifikátorů se bude ukazovat místo názvů poznámek v přehledovém pohledu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="138"/>
        <source>Visual qualifiers for %1</source>
        <translation>Viditelné modifikátory pro %1</translation>
    </message>
    <message>
        <location filename="../src/util_gui/AnnotationSettingsDialogImpl.cpp" line="139"/>
        <source>Please enter a comma-separated list of qualifier names.&lt;br&gt; &lt;i&gt;The value of qualifiers (with list priority) will be shown instead of the annotation names in PanView&lt;/i&gt;</source>
        <translation>Zadejte, prosím, čárkou oddělený seznam názvů modifikátorů&lt;br&gt; &lt;i&gt;Hodnota modifikátorů (s předností v seznamu) se bude ukazovat místo názvů poznámek v přehledovém pohledu&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>U2::CreateAnnotationDialog</name>
    <message>
        <source>create_button</source>
        <translation type="obsolete">Create</translation>
    </message>
    <message>
        <source>cancel_button</source>
        <translation type="obsolete">Cancel</translation>
    </message>
    <message>
        <source>invalid_state_info</source>
        <translation type="obsolete">Error</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationDialog.cpp" line="25"/>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationDialog.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationDialog.cpp" line="48"/>
        <source>Create annotation</source>
        <translation>Vytvořit poznámku</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationDialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>U2::CreateAnnotationWidgetController</name>
    <message>
        <source>group_name_auto</source>
        <translation type="obsolete">&lt;auto&gt;</translation>
    </message>
    <message>
        <source>save_file_dialog_caption</source>
        <translation type="obsolete">Save file</translation>
    </message>
    <message>
        <source>no_document_or_annotation_object_selected</source>
        <translation type="obsolete">Select annotation saving parameters</translation>
    </message>
    <message>
        <source>document_exists_%1</source>
        <translation type="obsolete">Document is already added to the project: &apos;%1&apos;</translation>
    </message>
    <message>
        <source>dir_not_exists_%1</source>
        <translation type="obsolete">Illegal folder: %1</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="90"/>
        <source>&lt;auto&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="136"/>
        <source>Save file</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="183"/>
        <source>Select annotation saving parameters</source>
        <translation>Vybrat parametry pro uložení poznámky</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="186"/>
        <source>Document is already added to the project: &apos;%1&apos;</source>
        <translation>Dokument je již přidán do projektu: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="192"/>
        <source>Illegal folder: %1</source>
        <translation>Neplatná složka: %1</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="198"/>
        <source>Annotation name is empty</source>
        <translation>Název poznámky je prázdný</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="203"/>
        <source>Annotation name is too long!
Maximum allowed size: %1 (Genbank format compatibility issue)</source>
        <translation type="unfinished">Název poznámky je příliš dlouhý: %1 (Genbank format compatibility issue)</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="208"/>
        <source>Illegal annotation name</source>
        <translation>Neplatný název poznámky</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="213"/>
        <source>Group name is empty</source>
        <translation>Název skupiny je prázdný</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="218"/>
        <source>Illegal group name</source>
        <translation>Neplatný název skupiny</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateAnnotationWidgetController.cpp" line="222"/>
        <source>Invalid location! Location must be in GenBank format.
Simple examples:
1..10
join(1..10,15..45)
complement(5..15)</source>
        <translation>Neplatné umístění</translation>
    </message>
</context>
<context>
    <name>U2::CreateDocumentFromTextDialogController</name>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="45"/>
        <source>Select file to save...</source>
        <translation>Vybrat soubor pro uložení...</translation>
    </message>
    <message>
        <source>Directory to save is not exists</source>
        <translation type="obsolete">Target directory does not exist</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="64"/>
        <source>No path specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="59"/>
        <source>Filename is empty</source>
        <translation>Název souboru pro uložení je prázdný</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="86"/>
        <source>warning</source>
        <translation type="unfinished">Warning!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="86"/>
        <source>The document already in the project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entered save filepath is empty</source>
        <translation type="obsolete">No path specified</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateDocumentFromTextDialogController.cpp" line="77"/>
        <source>Sequence name is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename to save is empty</source>
        <translation type="obsolete">Filename is empty</translation>
    </message>
</context>
<context>
    <name>U2::CreateObjectRelationDialogController</name>
    <message>
        <source>warning</source>
        <translation type="obsolete">Warning!</translation>
    </message>
    <message>
        <source>annotations_out_of_range</source>
        <translation type="obsolete">Annotations is out of the sequence range</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateObjectRelationDialogController.cpp" line="45"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../src/util_gui/CreateObjectRelationDialogController.cpp" line="46"/>
        <source>Found annotations that are out of the sequence range, continue?</source>
        <translation>Nalezeny poznámky, které jsou mimo rozsah sekvence. Pokračovat?</translation>
    </message>
</context>
<context>
    <name>U2::DownloadRemoteFileDialog</name>
    <message>
        <location filename="../src/util_gui/DownloadRemoteFileDialog.cpp" line="58"/>
        <source>Select directory to save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="obsolete">Error!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/DownloadRemoteFileDialog.cpp" line="91"/>
        <source>Resource id is empty!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/DownloadRemoteFileDialog.cpp" line="97"/>
        <source>No directory selected for saving file!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::EditQualifierDialog</name>
    <message>
        <location filename="../src/util_gui/EditQualifierDialog.cpp" line="63"/>
        <location filename="../src/util_gui/EditQualifierDialog.cpp" line="67"/>
        <source>Error!</source>
        <translation>Chyba!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditQualifierDialog.cpp" line="63"/>
        <source>Illegal qualifier name</source>
        <translation>Neplatný název modifikátoru</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditQualifierDialog.cpp" line="67"/>
        <source>Illegal qualifier value</source>
        <translation>Neplatná hodnota modifikátoru</translation>
    </message>
</context>
<context>
    <name>U2::EditSequenceDialogController</name>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="26"/>
        <source>Insert sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="28"/>
        <source>Replace sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="60"/>
        <source>Directory to save is not exists</source>
        <translation>Cílový adresář neexistuje</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="64"/>
        <source>Entered path is empty</source>
        <translation>Zadaná cesta je prázdná</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="68"/>
        <source>Filename is empty</source>
        <translation>Název souboru pro uložení je prázdný</translation>
    </message>
    <message>
        <location filename="../src/util_gui/EditSequenceDialogController.cpp" line="86"/>
        <source>Select file to save...</source>
        <translation>Vybrat soubor pro uložení...</translation>
    </message>
</context>
<context>
    <name>U2::GObjectView</name>
    <message>
        <source>object_is_already_added_to_view_%1</source>
        <translation type="obsolete">Object is already added to view %1!</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewModel.cpp" line="81"/>
        <source>Object is already added to view %1!</source>
        <translation>Předmět je již přidán do pohledu %1!</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewModel.cpp" line="95"/>
        <source>Can&apos;t add object: %1</source>
        <translation>Nelze přidat předmět: %1</translation>
    </message>
</context>
<context>
    <name>U2::GUIUtils</name>
    <message>
        <source>error</source>
        <translation type="obsolete">Error!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/GUIUtils.cpp" line="99"/>
        <location filename="../src/util_gui/GUIUtils.cpp" line="109"/>
        <location filename="../src/util_gui/GUIUtils.cpp" line="127"/>
        <source>Error!</source>
        <translation>Chyba!</translation>
    </message>
    <message>
        <location filename="../src/util_gui/GUIUtils.cpp" line="99"/>
        <source>Document URL is empty!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/GUIUtils.cpp" line="109"/>
        <source>Unable to launch default web browser.</source>
        <translation>Nelze spustit výchozí internetový prohlížeč.</translation>
    </message>
    <message>
        <location filename="../src/util_gui/GUIUtils.cpp" line="127"/>
        <source>Please specify the browser executable</source>
        <translation>Zadejte, prosím, spustitelný soubor prohlížeče</translation>
    </message>
    <message>
        <source>setup_web_browser</source>
        <translation type="obsolete">Please specify the browser executable</translation>
    </message>
    <message>
        <source>url_is_empty</source>
        <translation type="obsolete">Document URL is empty!</translation>
    </message>
</context>
<context>
    <name>U2::Header</name>
    <message>
        <location filename="../src/NotificationWidget.cpp" line="26"/>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/NotificationWidget.cpp" line="27"/>
        <source>Always on top</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LoadRemoteDocumentAndOpenViewTask</name>
    <message>
        <location filename="../src/OpenViewTask.cpp" line="176"/>
        <location filename="../src/OpenViewTask.cpp" line="182"/>
        <source>Load remote document and open view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/OpenViewTask.cpp" line="213"/>
        <source>Cannot find %1 in %2 database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LoadUnloadedDocumentAndOpenViewTask</name>
    <message>
        <location filename="../src/OpenViewTask.cpp" line="43"/>
        <source>Load document: &apos;%1&apos;</source>
        <translation>Nahrát dokument: &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::LogViewWidget</name>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="47"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="52"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="56"/>
        <source>Dump performance counters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="59"/>
        <source>Append separator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="61"/>
        <source>Clear log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="97"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="175"/>
        <source>logview_set_case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/util_gui/logview/LogView.cpp" line="178"/>
        <source>logview_use_regexp</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::MultiPartDocFormatConfigurator</name>
    <message>
        <source>%1_format_settings</source>
        <translation type="obsolete">%1 format settings</translation>
    </message>
    <message>
        <location filename="../src/util_gui/BaseDocumentFormatConfigurators.cpp" line="53"/>
        <source>%1 format settings</source>
        <translation>%1 nastavení formátu</translation>
    </message>
</context>
<context>
    <name>U2::Notification</name>
    <message>
        <location filename="../src/Notification.cpp" line="123"/>
        <source>Remove notification after closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Notification.cpp" line="138"/>
        <source>Detailed message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ObjectViewTask</name>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="18"/>
        <source>Update &apos;%1&apos; to &apos;%2&apos; state</source>
        <translation>Obnovit &apos;%1&apos; na stav &apos;%2&apos;</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="27"/>
        <source>Open new &apos;%1&apos;</source>
        <translation>Otevřít nový &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/ObjectViewTasks.cpp" line="29"/>
        <source>Open &apos;%1&apos;</source>
        <translation>Otevřít &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::ObjectViewTreeController</name>
    <message>
        <source>activate_view_action</source>
        <translation type="obsolete">Activate view</translation>
    </message>
    <message>
        <source>add_bookmark</source>
        <translation type="obsolete">Add bookmark</translation>
    </message>
    <message>
        <source>remove_bookmark</source>
        <translation type="obsolete">Remove bookmark</translation>
    </message>
    <message>
        <source>rename_bookmark</source>
        <translation type="obsolete">Rename bookmark</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="33"/>
        <source>Activate view</source>
        <translation>Zapnout pohled</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="38"/>
        <source>Add bookmark</source>
        <translation>Přidat záložku</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="42"/>
        <source>Remove bookmark</source>
        <translation>Odstranit záložku</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="48"/>
        <source>Rename bookmark</source>
        <translation>Přejmenovat záložku</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ObjectViewTreeController.cpp" line="325"/>
        <source>New bookmark</source>
        <translation>Nová záložka</translation>
    </message>
</context>
<context>
    <name>U2::ProjectFileUtils</name>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="211"/>
        <source>Project version is not a double value</source>
        <translation>Verze projektu není zdvojená hodnota</translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="216"/>
        <source>Project file was created by a newer version of UGENE. Please update UGENE.</source>
        <translation>Soubor s projektem byl vytvořen v novější verzi UGENE. Aktualizujte, prosím, UGENE.</translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="222"/>
        <source>Not a valid UGENE project file %1</source>
        <translation>Není platným souborem s projektem UGENE: %1</translation>
    </message>
</context>
<context>
    <name>U2::ProjectParser10</name>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="293"/>
        <source>Can&apos;t find project file: %1, ignoring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="297"/>
        <source>Duplicate document found: %1, ignoring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ProjectParsing.cpp" line="337"/>
        <source>The last loaded state was locked by format</source>
        <translation>Poslední nahraný stav byl zamčen formátem</translation>
    </message>
</context>
<context>
    <name>U2::ProjectTreeController</name>
    <message>
        <source>remove_selected_documents_action</source>
        <translation type="obsolete">Remove selected documents</translation>
    </message>
    <message>
        <source>load_selected_documents_action</source>
        <translation type="obsolete">Load selected documents</translation>
    </message>
    <message>
        <source>add_submenu</source>
        <translation type="obsolete">Add</translation>
    </message>
    <message>
        <source>remove_submenu</source>
        <translation type="obsolete">Remove</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="1080"/>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="1153"/>
        <source>[loading %1%]</source>
        <translation>[nahrává se %1%]</translation>
    </message>
    <message>
        <source>existing_document</source>
        <translation type="obsolete">Existing document</translation>
    </message>
    <message>
        <source>unload_sel_doc</source>
        <translation type="obsolete">Unload selected document</translation>
    </message>
    <message>
        <source>locks:</source>
        <translation type="obsolete">Locks:</translation>
    </message>
    <message>
        <source>project_is_locked</source>
        <translation type="obsolete">Project is locked</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="85"/>
        <source>Group by document</source>
        <translation>Seskupit podle dokumentu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="91"/>
        <source>Group by type</source>
        <translation>Seskupit podle typu</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="97"/>
        <source>No groups</source>
        <translation>Žádné skupiny</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="203"/>
        <source>Unloaded object refers to unloaded type: %1</source>
        <translation>Vyložené předměty odkazují na vyložené typy: %1</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="70"/>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="510"/>
        <source>Load selected documents</source>
        <translation>Nahrát vybrané dokumenty</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="64"/>
        <source>Remove selected documents</source>
        <translation>Odstranit vybrané dokumenty</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="82"/>
        <source>Unload selected document</source>
        <translation>Vyložit vybrané dokumenty</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="458"/>
        <source>Existing document</source>
        <translation>Stávající dokument</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="461"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="467"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="511"/>
        <source>Unload selected documents</source>
        <translation>Vyložit vybrané dokumenty</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="513"/>
        <source>Load selected objects</source>
        <translation>Nahrát vybrané předměty</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="514"/>
        <source>Unload selected objects</source>
        <translation>Vyložit vybrané předměty</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="1096"/>
        <source>Locks:</source>
        <translation>Zámky:</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="1099"/>
        <source>Project is locked</source>
        <translation>Projekt je uzamknut</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="76"/>
        <source>Lock document for editing</source>
        <translation>Zamknout dokument pro úpravy</translation>
    </message>
    <message>
        <location filename="../src/util_gui/ProjectTreeController.cpp" line="79"/>
        <source>Unlock document for editing</source>
        <translation>Odemknout dokument pro úpravy</translation>
    </message>
</context>
<context>
    <name>U2::RemovePartFromSequenceDialogController</name>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="49"/>
        <source>There must be only one region to delete</source>
        <translation>Je povolena pouze jedna oblast</translation>
    </message>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="53"/>
        <source>Unable to parse region to delete</source>
        <translation>Nelze zpracovat cílovou oblast</translation>
    </message>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="59"/>
        <source>Cannot remove the whole sequence</source>
        <translation>Nelze odstranit celou sekvenci</translation>
    </message>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="64"/>
        <source>Region to delete is out of sequence bounds</source>
        <translation>Cílová oblast je mimo hranic sekvence</translation>
    </message>
    <message>
        <location filename="../src/util_gui/RemovePartFromSequenceDialogController.cpp" line="75"/>
        <source>Select file to save...</source>
        <translation>Vybrat soubor pro uložení...</translation>
    </message>
</context>
<context>
    <name>U2::SaveDocumentGroupController</name>
    <message>
        <location filename="../src/util_gui/SaveDocumentGroupController.cpp" line="18"/>
        <source>Select file location</source>
        <translation>Vybrat umístění souboru</translation>
    </message>
</context>
<context>
    <name>U2::UnloadDocumentTask</name>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="26"/>
        <source>Unload document task: %1</source>
        <translation>Úkol vyložení dokumentu: %1</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="82"/>
        <source>Question?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="82"/>
        <source>Save document: %1</source>
        <translation>Uložit dokument: %1</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="101"/>
        <source>Failed to unload document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="105"/>
        <source>Failed to unload document: %1, error: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="114"/>
        <source>There is an active view with document content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="119"/>
        <source>Document is locked by some algorithm and cannot be unloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unload_document_%1</source>
        <translation type="obsolete">Unload document task: %1</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="40"/>
        <source>Document &apos;%1&apos; can&apos;t be unloaded: </source>
        <translation>Dokument &apos;%1&apos; nelze vyložit:</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="43"/>
        <source>save failed!</source>
        <translation>Uložení se nezdařilo!</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="54"/>
        <source>unexpected error</source>
        <translation>Neočekávaná chyba</translation>
    </message>
    <message>
        <source>save_doc_title</source>
        <translation type="obsolete">Question?</translation>
    </message>
    <message>
        <source>save_doc_text: %1</source>
        <translation type="obsolete">Save document: %1</translation>
    </message>
    <message>
        <source>document_failed_to_unload:</source>
        <translation type="obsolete">Failed to unload document</translation>
    </message>
    <message>
        <location filename="../src/UnloadDocumentTask.cpp" line="107"/>
        <source>Warning</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <source>document has active views</source>
        <translation type="obsolete">There is an active view with document content</translation>
    </message>
    <message>
        <source>document is live-locked</source>
        <translation type="obsolete">Document is locked by some algorithm and can&apos;t be unloaded</translation>
    </message>
</context>
</TS>
